# Fedimg

Fedimg is a service to automatically upload successful Fedora image builds to internal
and external cloud providers.

## License

Fedimg is licensed under AGPLv3+. See the source code for the [full license
text](https://github.com/fedora-infra/fedimg/blob/develop/LICENSE).

## Contributors

Fedimg was written by David Gay with contributions from Ralph Bean.
